# Build man pages
%global with_manpages 1

%bcond_without check

# https://github.com/git-lfs/git-lfs
%global goipath         github.com/git-lfs/git-lfs
Version:                3.4.1

# golang doesn't ship i686 binaries, we don't need the build
# https://bugzilla.redhat.com/show_bug.cgi?id=1752991#c9
%global golang_arches %(echo %{golang_arches} | sed "s|%{ix86}||")
%gometa

%global gobuilddir %{_builddir}/%{name}-%{version}/_build

# define gobuild macro to not lose hardening, because of macro conflict
# https://bugzilla.redhat.com/show_bug.cgi?id=1919348
%global gobuild CGO_CPPFLAGS="-D_FORTIFY_SOURCE=2 -fstack-protector-all" go build -compiler gc -buildmode pie '-tags=rpm_crashtraceback libtrust_openssl ' -ldflags "-linkmode=external -compressdwarf=false ${LDFLAGS:-} -B 0x$(head -c20 /dev/urandom|od -An -tx1|tr -d ' \\n') -extldflags '%__global_ldflags'" -a -v -x %{?**}

Name:           git-lfs
Release:        5%{?dist}
Summary:        Git extension for versioning large files

License:        MIT
URL:            https://git-lfs.github.io/
Source0:        https://github.com/%{name}/%{name}/releases/download/v%{version}/%{name}-v%{version}.tar.gz
Source1:        manpages.tgz
# See this script. Generating of manpages is performed on other distros due to some missing rubygem-asciidoctor on RHEL-8
Source2:        gen-manpages.sh

# https://github.com/advisories/GHSA-q6r2-x2cc-vrp7
# Backports 268628b, 4423696, 0345b6f and f6904cc that resolves the CVE-2024-53263
# Aditionally backports b326b63
# Commits had to be adapted as git-lfs-3.4.1 doesn't support multistage authentication
Patch:          git-lfs-3.4.1-cve-2024-53263.patch

# Generated provides by vendor2provides.py
# https://src.fedoraproject.org/rpms/syncthing/blob/603e4e03a92a7d704d199629dd85304018e8279d/f/vendor2provides.py
Provides:       bundled(golang(github.com/alexbrainman/sspi)) = 909beea
Provides:       bundled(golang(github.com/avast/retry-go)) = 2.4.2+incompatible
Provides:       bundled(golang(github.com/davecgh/go-spew)) = 1.1.1
Provides:       bundled(golang(github.com/dpotapov/go-spnego)) = 298b63a
Provides:       bundled(golang(github.com/git-lfs/gitobj/v2)) = 2.1.1
Provides:       bundled(golang(github.com/git-lfs/go-netrc)) = f0c862d
Provides:       bundled(golang(github.com/git-lfs/pktline)) = 06e9096
Provides:       bundled(golang(github.com/git-lfs/wildmatch/v2)) = 2.0.1
Provides:       bundled(golang(github.com/hashicorp/go-uuid)) = 1.0.2
Provides:       bundled(golang(github.com/inconshreveable/mousetrap)) = 1.0.1
Provides:       bundled(golang(github.com/jcmturner/aescts/v2)) = 2.0.0
Provides:       bundled(golang(github.com/jcmturner/dnsutils/v2)) = 2.0.0
Provides:       bundled(golang(github.com/jcmturner/gofork)) = 1.0.0
Provides:       bundled(golang(github.com/jcmturner/goidentity/v6)) = 6.0.1
Provides:       bundled(golang(github.com/jcmturner/gokrb5/v8)) = 8.4.2
Provides:       bundled(golang(github.com/jcmturner/rpc/v2)) = 2.0.3
Provides:       bundled(golang(github.com/leonelquinteros/gotext)) = 1.5.0
Provides:       bundled(golang(github.com/mattn/go-isatty)) = 0.0.4
Provides:       bundled(golang(github.com/olekukonko/ts)) = 78ecb04
Provides:       bundled(golang(github.com/pkg/errors)) = c605e28
Provides:       bundled(golang(github.com/pmezard/go-difflib)) = 1.0.0
Provides:       bundled(golang(github.com/rubyist/tracerx)) = 7879593
Provides:       bundled(golang(github.com/spf13/cobra)) = 1.6.0
Provides:       bundled(golang(github.com/spf13/pflag)) = 1.0.5
Provides:       bundled(golang(github.com/ssgelm/cookiejarparser)) = 1.0.1
Provides:       bundled(golang(github.com/stretchr/testify)) = 1.6.1
Provides:       bundled(golang(github.com/xeipuuv/gojsonpointer)) = 4e3ac27
Provides:       bundled(golang(github.com/xeipuuv/gojsonreference)) = bd5ef7b
Provides:       bundled(golang(github.com/xeipuuv/gojsonschema)) = 6b67b3f
Provides:       bundled(golang(golang.org/x/crypto)) = 7b82a4e
Provides:       bundled(golang(golang.org/x/net)) = 0.7.0
Provides:       bundled(golang(golang.org/x/sync)) = 0.1.0
Provides:       bundled(golang(golang.org/x/sys)) = 0.5.0
Provides:       bundled(golang(golang.org/x/text)) = 0.7.0
Provides:       bundled(golang(gopkg.in/yaml.v3)) = 3.0.1


%if 0%{?with_check}
# For tests
BuildRequires:  perl-Digest-SHA
BuildRequires:  perl-Test-Harness
# Tests require full git suite, but not generally needed.
BuildRequires:  git >= 2.32.0
%endif

Requires:       git-core >= 2.32.0

%description
Git Large File Storage (LFS) replaces large files such as audio samples,
videos, datasets, and graphics with text pointers inside Git, while
storing the file contents on a remote server.


%prep
%autosetup -p1 -n %{name}-%{version}

install -m 0755 -vd %{gobuilddir}/bin
install -m 0755 -vd "$(dirname %{gobuilddir}/src/%{goipath})"
ln -fs "$(pwd)" "%{gobuilddir}/src/%{goipath}"

%if %{?with_manpages}
# Unpack manpages generated by %%{SOURCE2}
tar -xf %{SOURCE1}
%endif

# Modify tests so that they expect binaries where we build them.
sed -i -e 's!\.\./bin/!/%{gobuilddir}/bin/!g' t/Makefile
sed -i -e 's!^BINPATH=.\+!BINPATH="%{gobuilddir}/bin"!g' t/testenv.sh

%build
export GOPATH=%{gobuilddir}:%{gopath}
export GO111MODULE=off

# Build manpages first (some embedding in the executable is done.)
pushd docs
%gobuild -o mangen man/mangen.go
./mangen
# Removes unwanted source files
# https://bugzilla.redhat.com/show_bug.cgi?id=1852842
rm mangen man/mangen.go
popd

%gobuild -o %{gobuilddir}/bin/git-lfs %{goipath}

# Build test executables
pushd %{gobuilddir}/src/%{goipath}
for cmd in t/cmd/*.go; do
    %gobuild -o "%{gobuilddir}/bin/$(basename $cmd .go)" "$cmd"
done
%gobuild -o "%{gobuilddir}/bin/git-lfs-test-server-api" t/git-lfs-test-server-api/*.go
popd


%install
# In Fedora this is done by using %%gopkginstall
install -Dpm0755 %{gobuilddir}/bin/git-lfs %{buildroot}%{_bindir}/%{name}
install -d -p %{buildroot}%{_mandir}/man1/
install -Dpm0644 man/man1/*.1 %{buildroot}%{_mandir}/man1/
install -d -p %{buildroot}%{_mandir}/man5/
install -Dpm0644 man/man5/*.5 %{buildroot}%{_mandir}/man5/
install -d -p %{buildroot}%{_mandir}/man7/
install -Dpm0644 man/man7/*.7 %{buildroot}%{_mandir}/man7/

# Remove unwanted files from man folder
# https://bugzilla.redhat.com/show_bug.cgi?id=1852842
rm -r man/*


%post
%{_bindir}/%{name} install --system --skip-repo

%preun
if [ $1 -eq 0 ]; then
    %{_bindir}/%{name} uninstall --system --skip-repo
fi
exit 0


%if %{with check}
%check
PATH=%{buildroot}%{_bindir}:%{gobuilddir}/bin:$PATH \
# https://github.com/git-lfs/git-lfs/issues/5609
# tests fails when running with low level of parallelism
    make -C t PROVE_EXTRA_ARGS="-j40 -v"
%endif


%files
# In Fedora this is done by using %%gopkgfiles 
%doc README.md CHANGELOG.md docs
%license LICENSE.md
%{_bindir}/%{name}
%{_mandir}/man1/%{name}*.1*
%{_mandir}/man5/%{name}*.5*
%{_mandir}/man7/%{name}*.7*


%changelog
* Tue Jun 10 2025 Ondřej Pohořelský <opohorel@redhat.com> - 3.4.1-5
- Rebuild with new Golang
- Resolves: RHEL-89264

* Fri Jan 17 2025 Ondřej Pohořelský <opohorel@redhat.com> - 3.4.1-4
- Backport CVE-2024-53263 fixes
- Resolves: RHEL-73931

* Mon Sep 23 2024 Ondřej Pohořelský <opohorel@redhat.com> - 3.4.1-3
- Rebuild with new Golang
- Resolves: RHEL-57900

* Mon Apr 22 2024 Ondřej Pohořelský <opohorel@redhat.com> - 3.4.1-2
- Rebuild with new Golang
- Resolves: RHEL-32543, RHEL-28377, RHEL-28399, RHEL-28423

* Mon Dec 18 2023 Ondrej Pohorelsky <opohorel@redhat.com> - 3.4.1-1
- Update to version 3.4.1
- Resolves: RHEL-17102

* Mon Jan 30 2023 Ondrej Pohorelsky <opohorel@redhat.com> - 3.2.0-2
- Rebuild with Golang-1.19.4
- Resolves: #2163744

* Mon Jan 09 2023 Ondrej Pohorelsky <opohorel@redhat.com> - 3.2.0-1
- Update to version 3.2.0
- Resolves: #2139382

* Mon Jan 17 2022 Ondrej Pohorelsky <opohorel@redhat.com> - 2.13.3-2
- Define %%gobuild macro with proper ldflags
- Related: rhbz#2021549

* Tue Nov 23 2021 Ondrej Pohorelsky <opohorel@redhat.com> - 2.13.3-1
- Update to version 2.13.3
- Fixed round brackets in Provides
- Moved manpages.tgz to look-a-side cache
- Resolves: rhbz#2021549, rhbz#1870080, rhbz#1866441

* Wed Jul 1 2020 Ondrej Pohorelsky <opohorel@redhat.com> - 2.11.0-2
- Removed mangen source file
- Cleaned docs/man folder
- Resolves: rhbz#1852842

* Wed Jun 10 2020 Ondrej Pohorelsky <opohorel@redhat.com> - 2.11.0-1
- Update to version 2.11.0
- Resolves: rhbz#1783391

* Thu Jul 19 2018 Sebastian Kisela <skisela@redhat.com> - 2.4.1-3
- Add pregenerated manpages, due to missing dependency 'ronn' in rhel7.

* Wed Jul 18 2018 Sebastian Kisela <skisela@redhat.com> - 2.4.1-2
- Initial build for rh-git218-git-lfs-2.4.1

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.4.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Wed May 23 2018 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.4.1-1
- Update to latest release

* Mon May 21 2018 Carl George <carl@george.computer> - 2.4.0-3
- Fix %%preun to correctly remove the lfs filter on uninstall (rhbz#1580357)

* Mon Mar 12 2018 Carl George <carl@george.computer> - 2.4.0-2
- Add %%go_arches fallback to work around Koji issues

* Sun Mar 04 2018 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.4.0-1
- Update to latest release.

* Thu Feb 08 2018 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.3.4-6
- Add patches to build with Go 1.10.

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 2.3.4-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Mon Dec 04 2017 Carl George <carl@george.computer> - 2.3.4-4
- Use vendored libraries on RHEL
- Skip test on RHEL
- Don't build man pages on RHEL due to missing ronn
- Don't build html versions of man pages

* Fri Dec 01 2017 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.3.4-3
- Require git-core instead of git.

* Fri Nov 03 2017 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.3.4-2
- Patch tests to work on slow systems like arm and aarch builders.
- Fix "git lfs help" command.

* Fri Nov 03 2017 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.3.4-1
- Update to latest release.
- Run all tests during build.

* Fri Sep 01 2017 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.2.1-3
- Remove redundant doc tag on manpages.
- Use path macros in %%post/%%postun.

* Thu Aug 31 2017 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.2.1-2
- Disable unnecessary subpackages.

* Sun Jul 30 2017 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.2.1-1
- Update to latest version.

* Wed Apr 19 2017 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.0.2-2
- Patch up to build with Go 1.7

* Wed Apr 19 2017 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.0.2-1
- Update to latest release
- Add some requested macros

* Tue Mar 14 2017 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.0.1-1
- Update to latest release
- Don't disable git-lfs globally during upgrade

* Mon Mar 06 2017 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 2.0.0-1
- Update to latest release

* Sun Feb 12 2017 Elliott Sales de Andrade <quantum.analyst@gmail.com> - 1.5.5-1
- Update to latest release
- Add -devel and -unit-test-devel subpackages
- Add post/preun scriptlets for global enablement

* Sun May 15 2016 Igor Gnatenko <i.gnatenko.brain@gmail.com> - 1.2.0-1
- Initial package
